# mypy-boto3-ses

[![PyPI - mypy-boto3-ses](https://img.shields.io/pypi/v/mypy-boto3-ses.svg?color=blue)](https://pypi.org/project/mypy-boto3-ses)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-ses.svg?color=blue)](https://pypi.org/project/mypy-boto3-ses)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.SES 1.14.31](https://boto3.amazonaws.com/v1/documentation/api/1.14.31/reference/services/ses.html#SES) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.2.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to install

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `SES` service.

```bash
python -m pip install boto3-stubs[ses]
```

## How to use

### Client annotations

`SESClient` provides annotations for `boto3.client("ses")`.

```python
import boto3

from mypy_boto3_ses import SESClient
from mypy_boto3_ses.paginator import (
    ListConfigurationSetsPaginator,
    ListCustomVerificationEmailTemplatesPaginator,
    ListIdentitiesPaginator,
    ListReceiptRuleSetsPaginator,
    ListTemplatesPaginator,
)
from mypy_boto3_ses.type_defs import AddHeaderActionTypeDef, ...
from mypy_boto3_ses.waiter import IdentityExistsWaiter

client: SESClient = boto3.client("ses")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: SESClient = session.client("ses")
```

### Paginators annotations

`mypy_boto3_ses.paginator` module contains type annotations for all paginators.

```python

client: SESClient = boto3.client("ses")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_configuration_sets_paginator: ListConfigurationSetsPaginator = client.get_paginator("list_configuration_sets")
list_custom_verification_email_templates_paginator: ListCustomVerificationEmailTemplatesPaginator = client.get_paginator("list_custom_verification_email_templates")
list_identities_paginator: ListIdentitiesPaginator = client.get_paginator("list_identities")
list_receipt_rule_sets_paginator: ListReceiptRuleSetsPaginator = client.get_paginator("list_receipt_rule_sets")
list_templates_paginator: ListTemplatesPaginator = client.get_paginator("list_templates")
```


### Waiters annotations

`mypy_boto3_ses.waiter` module contains type annotations for all waiters.

```python

client: SESClient = boto3.client("ses")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
identity_exists_waiter: IdentityExistsWaiter = client.get_waiter("identity_exists")
```





### Typed dictionations

`mypy_boto3_ses.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python

def get_structure() -> AddHeaderActionTypeDef:
    return {
      ...
    }
```


## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_ses` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("ses")

session_client = boto3.Session().client("ses")
```
